@@ -234,7 +234,7 @@ class DatadogDashboard(
             datadog_credentials=datadog_credentials,
         )
 
-        jsii.create(DatadogDashboard, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
 
 @jsii.data_type(
@@ -356,7 +356,7 @@ class DatadogDowntime(
             updater_id=updater_id,
         )
 
-        jsii.create(DatadogDowntime, self, [scope_, id_, props])
+        jsii.create(self.__class__, self, [scope_, id_, props])
 
 
 @jsii.data_type(
@@ -617,7 +617,7 @@ class DatadogIAMUser(
             verified=verified,
         )
 
-        jsii.create(DatadogIAMUser, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
 
 @jsii.data_type(
@@ -770,7 +770,7 @@ class DatadogMonitor(
             tags=tags,
         )
 
-        jsii.create(DatadogMonitor, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
 
 @jsii.data_type(
